import { defineStore } from 'pinia'

interface MarkStoreState {
  // 前端评卷试题的分值
  curQuestionScore: number | null
  // 倒计时相关状态
  countdownTime: number
  countdownTimer: NodeJS.Timeout | null
}

interface MarkStoreActions {
  setCurQuestionScore: (val: number | null) => void
  startCountdown: (markSpeedLimit?: number) => void
  clearCountdown: () => void
  updateCountdownTime: (time: number) => void
}

const useMarkStore = defineStore<'mark', MarkStoreState, Record<string, any>, MarkStoreActions>('mark', {
  state() {
    return {
      curQuestionScore: null,
      countdownTime: 0,
      countdownTimer: null,
    }
  },
  getters: {
    isCountingDown: (state: MarkStoreState) => state.countdownTime > 0,
    buttonText: (state: MarkStoreState) => (state.countdownTime > 0 ? `${state.countdownTime}s` : '确定'),
  },
  actions: {
    setCurQuestionScore(val: number | null) {
      this.curQuestionScore = val
    },

    startCountdown(markSpeedLimit?: number) {
      // 清除之前的计时器
      this.clearCountdown()

      if (!markSpeedLimit || markSpeedLimit <= 0) {
        this.countdownTime = 0
        return
      }

      this.countdownTime = markSpeedLimit
      this.countdownTimer = setInterval(() => {
        this.countdownTime--
        if (this.countdownTime <= 0) {
          this.clearCountdown()
        }
      }, 1000)
    },

    clearCountdown() {
      if (this.countdownTimer) {
        clearInterval(this.countdownTimer)
        this.countdownTimer = null
      }
      this.countdownTime = 0
    },

    updateCountdownTime(time: number) {
      this.countdownTime = time
    },
  },
})

export default useMarkStore
